DaemonController

Struct DaemonController 

pub struct DaemonController { /* private fields */ }
Controller to manage registered filesystem/blobcache/fscache services.

Implementations

Source

impl DaemonController

pub fn new() -> Self

Create a new instance of DaemonController.

pub fn is_active(&self) -> bool

Check whether the service controller is still in active/working state.

pub fn alloc_waker(&self) -> Arc<Waker>

Allocate a waker to notify stop events.

pub fn set_singleton_mode(&self, enabled: bool)

Enable/disable singleton mode.

pub fn set_daemon( &self, daemon: Arc<dyn NydusDaemon>, ) -> Option<Arc<dyn NydusDaemon>>

Set the daemon service object.

pub fn get_daemon(&self) -> Arc<dyn NydusDaemon>

Get the daemon service object.

Panic if called before set_daemon() has been called.

pub fn get_blob_cache_mgr(&self) -> Option<Arc<BlobCacheMgr>>

Get the optional blob cache manager.

pub fn set_blob_cache_mgr( &self, mgr: Arc<BlobCacheMgr>, ) -> Option<Arc<BlobCacheMgr>>

Set the optional blob cache manager.

pub fn set_fs_service( &self, service: Arc<dyn FsService>, ) -> Option<Arc<dyn FsService>>

Set the default fs service object.

pub fn get_fs_service(&self) -> Option<Arc<dyn FsService>>

Get the default fs service object.

pub fn notify_shutdown(&self)

Notify controller shutdown

pub fn shutdown(&self)

Shutdown all services managed by the controller.

pub fn run_loop(&self)

Run the event loop to handle service management events.