pub struct DaemonStateMachineContext { /* private fields */ }Expand description
An implementation of the state machine defined by DaemonStateMachine.
Implementations
Sourceimpl DaemonStateMachineContext
impl DaemonStateMachineContext
Sourcepub fn new(
daemon: Arc<dyn NydusDaemon>,
request_receiver: Receiver<DaemonStateMachineInput>,
result_sender: Sender<Result<()>>,
) -> Self
pub fn new( daemon: Arc<dyn NydusDaemon>, request_receiver: Receiver<DaemonStateMachineInput>, result_sender: Sender<Result<()>>, ) -> Self
Create a new instance of DaemonStateMachineContext.
Sourcepub fn kick_state_machine(self) -> Result<JoinHandle<Result<()>>>
pub fn kick_state_machine(self) -> Result<JoinHandle<Result<()>>>
Create a worker thread to run event loop for the state machine.